package de.uniulm.mathematik.typo.items;

/**
 * General interface for line-breaking algorithms which convert
 * a horizontal sequence into a vertical box consisting of individual
 * lines.
 */
public abstract class BasicLineBreaker implements LineBreaker {
   protected SequenceWrapper wrapper;
   protected ItemWrapper hboxwrapper;

   public BasicLineBreaker() {
      wrapper = null;
      hboxwrapper = null;
   }

   /**
    * Process each line by this wrapper before adding it
    * to the vertical box.
    */
   public void setLineWrapper(SequenceWrapper wrapper) {
      this.wrapper = wrapper;
   }

   /**
    * Process the horizontal box immediately before it
    * gets added to the vertical box.
    */
   public void setHorizontalBoxWrapper(ItemWrapper hboxwrapper) {
      this.hboxwrapper = hboxwrapper;
   }

   /**
    * Wrap a line if required, fit it into the given paragraph width,
    * and add it to a vertical box.
    */
   protected void add(VerticalBox vbox, HorizontalSequence line, int parwidth) {
      if (wrapper != null) {
	 line = wrapper.wrap(line);
      }
      HorizontalFitter.fit(line, parwidth);
      Item hbox = new HorizontalBox(line);
      if (hboxwrapper != null) {
	 hbox = hboxwrapper.wrap(hbox);
      }
      vbox.add(hbox);
   }

   /**
    * Break the horizontal sequence into individual lines that are
    * stacked up in a newly created vertical box that is returned.
    * @param hseq the horizontal sequence which is to be broken into
    *             lines. Note that the algorithm is free to adapt
    *             the widths of individual items of that sequence.
    * @param parwidth the width of the paragraph in units (1/1000 points).
    * @param baselineskip the vertical distance between the baselines
    *             of two subsequent lines in units (1/1000 points).
    */
   public abstract Item breakParagraph(HorizontalSequence hseq,
      int parwidth, int baselineskip);
} // class BasicLineBreaker
