package de.uniulm.mathematik.typo.items;

/**
 * A sequence wrapper maps horizontal sequences into a new
 * sequence that embeds the former. A ragged-right wrapper,
 * for example, would add a glue item with infinite
 * stretchability at the end.
 */
public class CenteringWrapper implements SequenceWrapper {
   private ItemWrapper iwrapper;

   /**
    * Construct a centering wrapper.
    */
   public CenteringWrapper() {
      iwrapper = null;
   }

   /**
    * Construct a centering wrapper that lets iwrapper wrap
    * all created glue items.
    */
   public CenteringWrapper(ItemWrapper iwrapper) {
      this.iwrapper = iwrapper;
   }

   /**
    * Create and return a new horizontal sequence that
    * creates a new sequence that consists of the old
    * sequence and a glue item of infinite stretchability.
    */
   public HorizontalSequence wrap(HorizontalSequence hseq) {
      HorizontalSequence s = new SimpleHorizontalSequence();
      Item glue1 = new Glue(0, Item.INFINITY, 0);
      if (iwrapper != null) {
	 glue1 = iwrapper.wrap(glue1);
      }
      s.add(glue1);
      s.add(hseq);
      Item glue2 = new Glue(0, Item.INFINITY, 0);
      if (iwrapper != null) {
	 glue2 = iwrapper.wrap(glue2);
      }
      s.add(glue2);
      return s;
   }
} // class CenteringWrapper
