package de.uniulm.mathematik.typo.items;

import de.uniulm.mathematik.typo.afm.*;

/**
 * The GlyphBox class supports boxes for individual glyphs,
 * e.g. letters and other symbols.
 */
public class GlyphBox extends Box {
   private FontMetrics fm;
   private int code;
   private int size;
   private int[] bbox;

   /**
    * Construct a glyph box:
    * @param fm The metrics of the selected font.
    * @param size The font size in points (not units!).
    * @param code The encoding of the glyph.
    */
   public GlyphBox(FontMetrics fm, int size, int code) {
      this.fm = fm;
      this.size = size;
      this.code = code;
      bbox = fm.getBoundingBox(code);
   }

   /**
    * Returns the width of the glyph in units (1/1000 points).
    * This value is derived from the width returned by the
    * associated font metrics. This is independent from the
    * bounding box.
    */
   public int getWidth() {
      return fm.getWidth(code) * size;
   }

   /**
    * Return the height of the glyph in units (1/1000 points).
    * This value is derived from the ury component of the bounding box.
    */
   public int getHeight() {
      int height = bbox[3] * size;
      if (height < 0) {
	 return 0;
      } else {
	 return height;
      }
   }

   /**
    * Return the depth of the glyph in units (1/1000 points).
    * This value is derived from the lly component of the bounding box.
    */
   public int getDepth() {
      int depth = - bbox[1] * size;
      if (depth < 0) {
	 return 0;
      } else {
	 return depth;
      }
   }

   /**
    * Generate PostScript text that generates the glyph.
    * @param context The context is used to combine multiple
    *                subsequent characters to PostScript strings
    *                as far as possible.
    */
   public StringBuffer genPostScript(PostScriptContext context) {
      return context.addTo(fm, size, code);
   }

   /**
    * Return a printable string representing the internal state.
    */
   public String toString() {
      return "glyph box " + (char) code + " of width " + getWidth();
   }
} // class GlyphBox
