package de.uniulm.mathematik.typo.items;

import de.uniulm.mathematik.typo.afm.*;

/**
 * Kerning boxes represent a fixed space with possible negative width
 * between two regular boxes.
 */
public class KerningBox extends Box {
   private int kerning;

   /**
    * Construct a kerning box with the given kerning value.
    * The kerning value is to be given in units (1/1000 points).
    */
   public KerningBox(int kerning) {
      this.kerning = kerning;
   }

   /**
    * Returns the width of the kerning box which is defined by
    * the kerning value.
    */
   public int getWidth() {
      return kerning;
   }

   /**
    * Returns 0.
    */
   public int getHeight() {
      return 0;
   }

   /**
    * Returns 0.
    */
   public int getDepth() {
      return 0;
   }

   /**
    * Generate a relative movement in PostScript according to
    * the kerning value.
    */
   public StringBuffer genPostScript(PostScriptContext context) {
      StringBuffer result = context.closeString();
      result.append((double) kerning / 1000);
      result.append(" 0 rmoveto\n");
      return result;
   }

   /**
    * Return a printable representation of the internal state.
    */
   public String toString() {
      return "kerning box " + kerning;
   }
} // class KerningBox
