package de.uniulm.mathematik.typo.items;

/**
 * Penalty items represent positions where a horizontal sequence 
 * may be split into lines.
 */
public class Penalty implements Item {
   private int penalty;
   private boolean flag;

   private int intoRange(int value) {
      if (value > Item.INFINITY) {
	 return Item.INFINITY;
      } else if (value < - Item.INFINITY) {
	 return -Item.INFINITY;
      } else {
	 return value;
      }
   }

   /**
    * Construct a penalty item
    * @param penalty the penalty value. The higher the penalty value
    *                the uglier the expected result if a sequence is
    *                broken up at this point.
    * @param flag    consecutive line breaks at flagged penalties are
    *                considered ugly.
    */
   public Penalty(int penalty, boolean flag) {
      this.penalty = intoRange(penalty);
      this.flag = flag;
   }

   /**
    * Returns true.
    */
   final public boolean isPenalty() {
      return true;
   }

   /**
    * Returns false.
    */
   final public boolean isGlue() {
      return false;
   }

   /**
    * Returns false.
    */
   final public boolean isBox() {
      return false;
   }

   /**
    * Returns 0.
    */
   public int getWidth() {
      return 0;
   }

   /**
    * Returns 0.
    */
   public int getStretchability() {
      return 0;
   }

   /**
    * Returns 0.
    */
   public int getShrinkability() {
      return 0;
   }

   /**
    * Invocations of this method are ignored.
    */
   public void shrink(int units) {}

   /**
    * Invocations of this method are ignored.
    */
   public void stretch(int units) {}

   /**
    * Returns 0.
    */
   public int getHeight() {
      return 0;
   }

   /**
    * Returns 0.
    */
   public int getDepth() {
      return 0;
   }

   /**
    * Return the penalty value of this penalty item.
    */
   public int getPenalty() {
      return penalty;
   }

   /**
    * Return true, if this penalty item is flagged.
    */
   public boolean getPenaltyFlag() {
      return flag;
   }

   /**
    * Returns null but extensions may override this.
    */
   public Item getHyphen() {
      return null;
   }

   /**
    * Returns an empty string.
    */
   public StringBuffer genPostScript(PostScriptContext context) {
      return new StringBuffer("");
   }

   /**
    * Returns a printable representation of the internal state.
    */
   public String toString() {
      StringBuffer text = new StringBuffer("");
      if (flag) {
	 text.append("flagged ");
      }
      text.append("penalty box with a value of " + penalty);
      return text.toString();
   }
} // class Penalty
