package de.uniulm.mathematik.typo.items;

/**
 * A sequence wrapper maps horizontal sequences into a new
 * sequence that embeds the former. A ragged-right wrapper,
 * for example, would add a glue item with infinite
 * stretchability at the end.
 */
public class RaggedRightWrapper implements SequenceWrapper {
   private ItemWrapper iwrapper;

   public RaggedRightWrapper() {
      iwrapper = null;
   }

   public RaggedRightWrapper(ItemWrapper iwrapper) {
      this.iwrapper = iwrapper;
   }

   /**
    * Create and return a new horizontal sequence that
    * creates a new sequence that consists of the old
    * sequence and a glue item of infinite stretchability.
    */
   public HorizontalSequence wrap(HorizontalSequence hseq) {
      HorizontalSequence s = hseq.clone();
      Item glue = new Glue(0, Item.INFINITY, 0);
      if (iwrapper != null) {
	 glue = iwrapper.wrap(glue);
      }
      s.add(glue);
      return s;
   }
} // class RaggedRightWrapper
